@@ -10,7 +10,7 @@ import (
 //doc:after   x.String()
 func redundantSprint(m dsl.Matcher) {
 	m.Match(`fmt.Sprint($x)`, `fmt.Sprintf("%s", $x)`, `fmt.Sprintf("%v", $x)`).
-		Where(m["x"].Type.Implements(`fmt.Stringer`)).
+		Where(!m["x"].Type.Is(`reflect.Value`) && m["x"].Type.Implements(`fmt.Stringer`)).
 		Suggest(`$x.String()`).
 		Report(`use $x.String() instead`)
 
@@ -118,14 +118,12 @@ func httpNoBody(m dsl.Matcher) {
 	m.Match("http.NewRequest($method, $url, $nil)").
 		Where(m["nil"].Text == "nil").
 		Suggest("http.NewRequest($method, $url, http.NoBody)").
-		Report("http.NoBody should be preferred to the nil request body").
-		At(m["nil"])
+		Report("http.NoBody should be preferred to the nil request body")
 
 	m.Match("http.NewRequestWithContext($ctx, $method, $url, $nil)").
 		Where(m["nil"].Text == "nil").
 		Suggest("http.NewRequestWithContext($ctx, $method, $url, http.NoBody)").
-		Report("http.NoBody should be preferred to the nil request body").
-		At(m["nil"])
+		Report("http.NoBody should be preferred to the nil request body")
 }
 
 //doc:summary Detects expressions like []rune(s)[0] that may cause unwanted rune slice allocation
@@ -771,3 +769,19 @@ func stringsCompare(m dsl.Matcher) {
 		`strings.Compare($s1, $s2) > 0`).
 		Suggest(`$s1 > $s2`)
 }
+
+//doc:summary   Detects unchecked errors in if statements
+//doc:tags      diagnostic experimental
+//doc:before    if err := expr(); err2 != nil { /*...*/ }
+//doc:after     if err := expr(); err != nil { /*...*/ }
+func uncheckedInlineErr(m dsl.Matcher) {
+	m.Match(
+		`if $err := $_($*_); $err2 != nil { $*_ }`,
+		`if $err = $_($*_); $err2 != nil { $*_ }`,
+		`if $*_, $err := $_($*_); $err2 != nil { $*_ }`,
+		`if $*_, $err = $_($*_); $err2 != nil { $*_ }`).
+		Where(m["err"].Type.Implements("error") && m["err2"].Type.Implements("error") &&
+			m["err"].Text != m["err2"].Text).
+		Report("$err error is unchecked, maybe intended to check it instead of $err2").
+		At(m["err"])
+}
