@@ -2,8 +2,9 @@ package main
 
 import (
 	"bytes"
-	"io/ioutil"
 	"log"
+	"os"
+	"strings"
 	"text/template"
 
 	_ "github.com/go-critic/go-critic/checkers"
@@ -30,7 +31,7 @@ func main() {
 	if err != nil {
 		log.Fatalf("render template: %v", err)
 	}
-	if err := ioutil.WriteFile(docsPath+"overview.md", buf.Bytes(), 0o600); err != nil {
+	if err := os.WriteFile(docsPath+"overview.md", buf.Bytes(), 0o600); err != nil {
 		log.Fatalf("write output file: %v", err)
 	}
 }
@@ -40,5 +41,8 @@ func parseTemplate(names ...string) *template.Template {
 	for i := range names {
 		paths[i] = templatesPath + names[i]
 	}
-	return template.Must(template.ParseFiles(paths...))
+	funcMap := template.FuncMap{
+		"ToLower": strings.ToLower,
+	}
+	return template.Must(template.New("overview").Funcs(funcMap).ParseFiles(paths...))
 }
